@@ -41,6 +41,8 @@ iDeclareType(Root)
 iDeclareType(Visited)
 iDeclareType(Window)
 
+typedef void iAnyWindow;
+
 /* Command line options strings. */
 #define dump_CommandLineOption              "dump;d"
 #define dumpIdentity_CommandLineOption      "dump-identity;I"
@@ -81,13 +83,14 @@ const iString *downloadDir_App  (void);
 const iString *debugInfo_App    (void);
 
 int         run_App                     (int argc, char **argv);
-void        rootOrder_App               (iRoot *roots[2]); /* TODO: max roots? */
 void        processEvents_App           (enum iAppEventMode mode);
 iBool       handleCommand_App           (const char *cmd);
 void        refresh_App                 (void);
 iBool       isRefreshPending_App        (void);
 iBool       isFinishedLaunching_App     (void);
 uint32_t    elapsedSinceLastTicker_App  (void); /* milliseconds */
+void        disableRefresh_App          (iBool);
+void        setTextInputActive_App      (iBool);
 
 iBool               isLandscape_App     (void);
 iLocalDef iBool     isPortrait_App      (void) { return !isLandscape_App(); }
@@ -95,6 +98,7 @@ enum iAppDeviceType deviceType_App      (void);
 iLocalDef iBool     isPortraitPhone_App (void) { return isPortrait_App() && deviceType_App() == phone_AppDeviceType; }
 iLocalDef iBool     isLandscapePhone_App(void) { return isLandscape_App() && deviceType_App() == phone_AppDeviceType; }
 iBool               isRunningUnderWindowSystem_App  (void);
+iBool               isTextInputActive_App           (void);
 
 const iCommandLine *commandLine_App     (void);
 iGmCerts *          certs_App           (void);
@@ -134,16 +138,21 @@ void        removeTicker_App    (iTickerFunc ticker, iAny *context);
 
 void        addWindow_App       (iMainWindow *win);
 void        removeWindow_App    (iMainWindow *win);
-void        setActiveWindow_App (iMainWindow *win);
-void        closeWindow_App     (iMainWindow *win);
+void        setActiveWindow_App (iAnyWindow *mainOrExtraWin);
+iWindow *   activeWindow_App    (void);
+void        closeWindow_App     (iWindow *win); /* main or extra window */
 size_t      numWindows_App      (void);
 size_t      windowIndex_App     (const iMainWindow *win);
 iMainWindow *newMainWindow_App  (void);
 const iPtrArray *mainWindows_App(void);
+const iPtrArray *regularWindows_App(void);
 iMainWindow *    mainWindow_App (void); /* currently active main window */
+void        addExtraWindow_App  (iWindow *extra);
+void        removeExtraWindow_App(iWindow *extra);
 void        addPopup_App        (iWindow *popup);
 void        removePopup_App     (iWindow *popup);
 void        closePopups_App     (iBool doForce);
+iWindow *   findWindow_App      (int windowType, const char *widgetId);
 
 void        postRefresh_App     (void);
 void        postCommand_Root    (iRoot *, const char *command);
